@@ -1,4 +1,5 @@
 from .between import between
+from .btc_address import btc_address
 from .card import (
     amex,
     card_number,
@@ -29,6 +30,6 @@ __all__ = ('between', 'domain', 'email', 'Max', 'Min', 'md5', 'sha1', 'sha224',
            'ipv4_cidr', 'ipv6', 'ipv6_cidr', 'length', 'mac_address', 'slug',
            'truthy', 'url', 'ValidationFailure', 'validator', 'uuid',
            'card_number', 'visa', 'mastercard', 'amex', 'unionpay', 'diners',
-           'jcb', 'discover')
+           'jcb', 'discover', 'btc_address')
 
-__version__ = '0.17.0'
+__version__ = '0.19.0'
